==> cppcheck-1.0.0.tar.gz: cppcheck-1.0.0/README.md <==
# Cppcheck Wheel

<!-- SPHINX-START -->

Package cppcheck as a python wheel.

[![Documentation](https://img.shields.io/badge/Documentation-sphinx-blue)](https://msclock.github.io/cppcheck-wheel)
[![License](https://img.shields.io/github/license/msclock/cppcheck-wheel)](https://github.com/msclock/cppcheck-wheel/blob/master/LICENSE)
[![SS Cpp](https://img.shields.io/badge/Serious%20Scaffold-pybind11-blue)](https://github.com/serious-scaffold/ss-pybind11)

[![CI](https://github.com/msclock/cppcheck-wheel/actions/workflows/ci.yml/badge.svg)](https://github.com/msclock/cppcheck-wheel/actions/workflows/ci.yml)
[![CD](https://github.com/msclock/cppcheck-wheel/actions/workflows/cd.yml/badge.svg)](https://github.com/msclock/cppcheck-wheel/actions/workflows/cd.yml)
[![Renovate](https://github.com/msclock/cppcheck-wheel/actions/workflows/renovate.yml/badge.svg)](https://github.com/msclock/cppcheck-wheel/actions/workflows/renovate.yml)
[![Semantic Release](https://github.com/msclock/cppcheck-wheel/actions/workflows/semantic-release.yml/badge.svg)](https://github.com/msclock/cppcheck-wheel/actions/workflows/semantic-release.yml)
[![codecov](https://codecov.io/gh/msclock/cppcheck-wheel/branch/master/graph/badge.svg?token=123456789)](https://codecov.io/gh/msclock/cppcheck-wheel)
[![Release](https://img.shields.io/github/v/release/msclock/cppcheck-wheel)](https://github.com/msclock/cppcheck-wheel/releases)

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![clang-format](https://img.shields.io/badge/clang--format-enabled-blue)](https://github.com/pre-commit/mirrors-clang-format)
[![cmake-format](https://img.shields.io/badge/cmake--format-enabled-blue)](https://github.com/cheshirekow/cmake-format-precommit)
[![codespell](https://img.shields.io/badge/codespell-enabled-blue)](https://github.com/codespell-project/codespell)
[![markdownlint](https://img.shields.io/badge/markdownlint-enabled-blue)](https://github.com/igorshubovych/markdownlint-cli)
[![shellcheck](https://img.shields.io/badge/shellcheck-enabled-blue)](https://github.com/shellcheck-py/shellcheck-py)

<!-- writes more things here -->

## Install

Package-built has uploaded to pypi and just install with the command:

```bash
pip install cppcheck
```

## License

Apache Software License, for more details, see the [LICENSE](https://github.com/msclock/cppcheck-wheel/blob/master/LICENSE) file.

==> cppcheck-1.4.2.tar.gz: cppcheck-1.4.2/README.md <==
# Cppcheck Wheel

<!-- SPHINX-START -->

Package cppcheck as a python wheel.

[![Documentation](https://img.shields.io/badge/Documentation-sphinx-blue)](https://msclock.github.io/cppcheck-wheel)
[![License](https://img.shields.io/github/license/msclock/cppcheck-wheel)](https://github.com/msclock/cppcheck-wheel/blob/master/LICENSE)
[![SS Badge](https://img.shields.io/badge/Serious%20Scaffold-pybind11-blue)](https://github.com/serious-scaffold/ss-pybind11)

[![CI](https://github.com/msclock/cppcheck-wheel/actions/workflows/ci.yml/badge.svg)](https://github.com/msclock/cppcheck-wheel/actions/workflows/ci.yml)
[![CD](https://github.com/msclock/cppcheck-wheel/actions/workflows/cd.yml/badge.svg)](https://github.com/msclock/cppcheck-wheel/actions/workflows/cd.yml)
[![Renovate](https://github.com/msclock/cppcheck-wheel/actions/workflows/renovate.yml/badge.svg)](https://github.com/msclock/cppcheck-wheel/actions/workflows/renovate.yml)
[![Semantic Release](https://github.com/msclock/cppcheck-wheel/actions/workflows/semantic-release.yml/badge.svg)](https://github.com/msclock/cppcheck-wheel/actions/workflows/semantic-release.yml)
[![codecov](https://codecov.io/gh/msclock/cppcheck-wheel/branch/master/graph/badge.svg?token=123456789)](https://codecov.io/gh/msclock/cppcheck-wheel)
[![Release](https://img.shields.io/github/v/release/msclock/cppcheck-wheel)](https://github.com/msclock/cppcheck-wheel/releases)

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![cmake-format](https://img.shields.io/badge/cmake--format-enabled-blue)](https://github.com/cheshirekow/cmake-format-precommit)
[![codespell](https://img.shields.io/badge/codespell-enabled-blue)](https://github.com/codespell-project/codespell)
[![markdownlint](https://img.shields.io/badge/markdownlint-enabled-blue)](https://github.com/igorshubovych/markdownlint-cli)
[![shellcheck](https://img.shields.io/badge/shellcheck-enabled-blue)](https://github.com/shellcheck-py/shellcheck-py)

<!-- writes more things here -->

## Install

Package-built has uploaded to pypi and just install with the command:

```bash
pip install cppcheck
```

## License

Apache Software License, for more details, see the [LICENSE](https://github.com/msclock/cppcheck-wheel/blob/master/LICENSE) file.
